@@ -23,4 +23,5 @@ class BookingAssistantFlowNotification:
       sns_service.send(self._app_config.BOOKING_ASSISTANT_SNS_TOPIC_ARN,
         self._app_config.BOOKING_ASSISTANT_SNS_SUBJECT, json.dumps(message))
     except Exception as e:
-      logger.exception(f"failed to send message to {self._app_config.BOOKING_ASSISTANT_SNS_TOPIC_ARN}: {message} - {e}", e)
+      logger.error(f"failed to send BookingAssistantFlowNotification message: {e}")
+      logger.error(f"BookingAssistantFlowNotification message: {message}")
