@@ -13,4 +13,4 @@ class SqsService:
 			DelaySeconds=delaySeconds,
 			MessageAttributes={}
 		)
-		return response.MessageId
\ No newline at end of file
+		return response.get('MessageId')
